Index: src/ppc/macro-assembler-ppc.h |
diff --git a/src/ppc/macro-assembler-ppc.h b/src/ppc/macro-assembler-ppc.h |
index fc569706ecb2ddf486da1dbff10556fdd2389b22..7c4915479fe1975a8a719adcbbe458b8c12e6c74 100644 |
--- a/src/ppc/macro-assembler-ppc.h |
+++ b/src/ppc/macro-assembler-ppc.h |
@@ -102,7 +102,9 @@ class MacroAssembler : public Assembler { |
MacroAssembler(Isolate* isolate, void* buffer, int size); |
- // Returns the size of a call in instructions. |
+ // Returns the size of a call in instructions. Note, the value returned is |
+ // only valid as long as no entries are added to the constant pool between |
+ // checking the call size and emitting the actual call. |
static int CallSize(Register target); |
int CallSize(Address target, RelocInfo::Mode rmode, Condition cond = al); |
static int CallSizeNotPredictableCodeSize(Address target, |
@@ -544,12 +546,12 @@ class MacroAssembler : public Assembler { |
// --------------------------------------------------------------------------- |
// Exception handling |
- // Push a new try handler and link into try handler chain. |
- void PushTryHandler(StackHandler::Kind kind, int handler_index); |
+ // Push a new stack handler and link into stack handler chain. |
+ void PushStackHandler(); |
- // Unlink the stack handler on top of the stack from the try handler chain. |
+ // Unlink the stack handler on top of the stack from the stack handler chain. |
// Must preserve the result register. |
- void PopTryHandler(); |
+ void PopStackHandler(); |
// --------------------------------------------------------------------------- |
// Inline caching support |
@@ -1360,7 +1362,7 @@ class MacroAssembler : public Assembler { |
// --------------------------------------------------------------------------- |
// Patching helpers. |
// Retrieve/patch the relocated value (lis/ori pair). |
void GetRelocatedValue(Register location, Register result, Register scratch); |
void SetRelocatedValue(Register location, Register scratch, |
Register new_value); |
@@ -1449,6 +1451,11 @@ class MacroAssembler : public Assembler { |
void JumpIfDictionaryInPrototypeChain(Register object, Register scratch0, |
Register scratch1, Label* found); |
+ // Loads the constant pool pointer (kConstantPoolRegister). |
+ void LoadTargetConstantPoolPointerRegister(Register target); |
+ void LoadOwnConstantPoolPointerRegister(Register base = no_reg, |
+ int code_entry_delta = 0); |
+ |
private: |
static const int kSmiShift = kSmiTagSize + kSmiShiftSize; |
@@ -1360,7 +1362,7 @@ class MacroAssembler : public Assembler { |
// --------------------------------------------------------------------------- |
// Patching helpers. |
- // Retrieve/patch the relocated value (lis/ori pair). |
+ // Retrieve/patch the relocated value (lis/ori pair or constant pool load). |
void GetRelocatedValue(Register location, Register result, Register scratch); |
void SetRelocatedValue(Register location, Register scratch, |